@@ -91,7 +91,7 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.back_2.clicked.connect(self.back_2)
         self.ui.back_3.clicked.connect(self.back_2)
         self.ui.back_4.clicked.connect(self.back_2)
-        self.ui.updater.clicked.connect(self.update)
+        #self.ui.updater.clicked.connect(self.update)
         self.ui.search.clicked.connect(self.search)
         self.ui.sound.toggled.connect(self.sound)
         self.ui.start_update.clicked.connect(self.updating)
